package com.kuyuntech.cofarcooking.device.sdk.devmode.standmixer;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorHeightSpeed;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.devmode.core.BaseDevMode;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.util.TimerTask;

@EqualsAndHashCode(callSuper = true)
@Data
@ToString
public class SmKnead extends BaseDevMode {

    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean autoPasue = false;

    private boolean stop = false;

    public SmKnead() {

        this.setMode(WorkModes.SM_KNEAD);
        this.setMinTime(2 * 60);
        this.setMaxTime(20 * 60);
        this.setDefaultTime(6 * 60);
        this.setDefaultMotorGear(1);
        this.setMinMotorGear(1);
        this.setMaxMotorGear(5);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(false);
        this.setMinTemp(0);
        this.setDefaultTemp(0);
        this.setMaxTemp(0);
        this.setTempChange(false);
        this.setDiyCountDown(true);
    }


    @Override
    public void start() {
        currentSec = 0L;
        CofarSDK.startNative();
        CofarSDK.cfgMotorGearNative((byte) 3);
        this.stop = false;
    }

    private int initMotorGear = -1;

    @Override
    public void onCountDown(TimerTask timer) {


        if (!pasue && DevStatus.PAUSE == CofarSDK.devInfo().getStatus()) {
            if (!autoPasue) {
                return;
            }
        }

        if (pasue) {
            return;
        }


        DevInfo devInfo = CofarSDK.devInfo();

        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown() && !stop) {
            this.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            this.stop(false);
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));

        if (initMotorGear == -1) {
            initMotorGear = devInfo.getMotorGear();
        }


        if (currentSec == 0) {
            CofarSDK.cfgMotorGearNative((byte) 1);
        }

        if (currentSec == 30) {
            CofarSDK.cfgMotorGearNative((byte) 2);
        }

        if (currentSec == 60) {
            CofarSDK.cfgMotorGearNative((byte) initMotorGear);
        }


        currentSec++;

    }

    private boolean startCount = false;


    @Override
    public boolean startCountTime() {

        if (this.startCount) {
            return this.startCount;
        }

        if (currentSec < 60) {
            this.startCount = true;
            return this.startCountTime();
        } else {
            return false;
        }


    }


    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        this.stop = true;
        this.pasue = false;
        CofarSDK.stopNative();
        super.stop();
    }

    @Override
    public void stop(boolean tips) {
        this.stop = true;
        this.pasue = false;
        super.stop(tips);
    }




}
